@@ -1377,6 +1377,7 @@ rdpClientConInit(rdpPtr dev)
             return 1;
         }
         g_sck_listen(dev->disconnect_sck);
+        g_chmod_hex(dev->disconnect_uds, 0x0660);
         rdpClientConAddEnabledDevice(dev->pScreen, dev->disconnect_sck);
     }
 
@@ -1401,7 +1402,6 @@ rdpClientConInit(rdpPtr dev)
         i = atoi(ptext);
         if (i > 0)
         {
-            dev->do_kill_disconnected = 1;
             dev->disconnect_timeout_s = atoi(ptext);
         }
     }
@@ -1409,7 +1409,11 @@ rdpClientConInit(rdpPtr dev)
     if (ptext != 0)
     {
         i = atoi(ptext);
-        if (i != 0)
+        if (i == 0)
+        {
+            dev->do_kill_disconnected = 0;
+        }
+        else
         {
             dev->do_kill_disconnected = 1;
         }
@@ -1444,7 +1448,11 @@ rdpClientConDeinit(rdpPtr dev)
         rdpClientConRemoveEnabledDevice(dev->listen_sck);
         g_sck_close(dev->listen_sck);
         LLOGLN(0, ("rdpClientConDeinit: deleting file %s", dev->uds_data));
-        unlink(dev->uds_data);
+        if (unlink(dev->uds_data) < 0)
+        {
+            LLOGLN(0, ("rdpClientConDeinit: failed to delete %s (%s)",
+                        dev->uds_data, strerror(errno)));
+        }
     }
 
     if (dev->disconnect_sck != 0)
@@ -1452,7 +1460,11 @@ rdpClientConDeinit(rdpPtr dev)
         rdpClientConRemoveEnabledDevice(dev->disconnect_sck);
         g_sck_close(dev->disconnect_sck);
         LLOGLN(0, ("rdpClientConDeinit: deleting file %s", dev->disconnect_uds));
-        unlink(dev->disconnect_uds);
+        if (unlink(dev->disconnect_uds) < 0)
+        {
+            LLOGLN(0, ("rdpClientConDeinit: failed to delete %s (%s)",
+                        dev->disconnect_uds, strerror(errno)));
+        }
     }
 
     return 0;
